@@ -182,6 +182,20 @@ class CreatorTestCase(unittest.TestCase):
             self.portal["a-folder"].contentIds(),
         )
 
+    def test_content_from_folder_with_excludes(self):
+        path = os.path.join(os.path.dirname(__file__), "content")
+
+        with api.env.adopt_roles(["Manager"]):
+            content_creator_from_folder(
+                folder_name=path, exclude=["a-folder.a-document-1"]
+            )
+
+        self.assertEqual(["front-page", "a-folder"], self.portal.contentIds())
+        self.assertEqual(
+            ["a-document-2", "a-document-3", "the-last-document"],
+            self.portal["a-folder"].contentIds(),
+        )
+
     def test_content_from_folder_custom_order(self):
         path = os.path.join(os.path.dirname(__file__), "content")
 
